==> designer-common-1.0.10-20251126.022212-3-sources.jar: com/digiwin/athena/constant/ModuleConstant.java <==
package com.digiwin.athena.constant;

/**
 * @author liyuetao
 * @title: ModuleConstant
 * @projectName athena_designer
 * @description: TODO
 * @date 2022/10/1715:43
 */
public interface ModuleConstant {
    /**
     * 数据录入
     */
    String DATA_ENTRY = "DataEntry";

    /**
     * 数据录入
     */
    String DATA_ENTRY_LCDP = "DataEntry_Lcdp";

    /**
     * 报表
     */
    String STATEMENT = "Statement";

    /**
     * 侦测
     */
    String MONITOR_RULE = "monitorRule";


    /**
     * 服务编排
     */
    String AD_TEMPLATE = "adTemplate";

    /**
     * 行动
     */
    String ACTION = "action";

    /**
     * 任务
     */
    String TASK = "task";

    /**
     * 活动
     */
    String ACTIVITY = "activity";

    /**
     * 流程
     */
    String FLOW_GRAPH = "flowGraph";

    /**
     * 驱动执行
     */
    String DTD = "dtd";

    /**
     * 模型驱动
     */
    String MODEL_DRIVEN = "modelDriven";

    /**
     * 机制
     */
    String MECHANISM = "mechanism";

    /**
     * 套件作业
     */
    String KIT_ASSIGN = "kitAssign";

    /**
     * 数据视图
     */
    String DATA_VIEW = "dataView";

    /**
     * 流程
     */
    String PROCESS = "process";

    /**
     * 事件
     */
    String EVENT = "event";

    /**
     * 数据流
     */
    String DATA_FLOW = "dataFlow";
    /**
     * 租户级流程
     */
    String TENANT_PROCESS = "tenant_process";

    /**
     * 移动端
     */
    String MOBILE_PAGE_DESIGN = "mobilePageDesign";

    /**
     * 场景
     */
    String SCENE = "scene";

    /**
     * 子页面
     */
    String SUB_PAGE = "subPage";

}

==> designer-common-1.0.10-20251204.093924-24-sources.jar: com/digiwin/athena/constant/ModuleConstant.java <==
package com.digiwin.athena.constant;

/**
 * @author liyuetao
 * @title: ModuleConstant
 * @projectName athena_designer
 * @description: TODO
 * @date 2022/10/1715:43
 */
public interface ModuleConstant {
    /**
     * 数据录入
     */
    String DATA_ENTRY = "DataEntry";

    /**
     * 数据录入
     */
    String DATA_ENTRY_LCDP = "DataEntry_Lcdp";

    /**
     * 报表
     */
    String STATEMENT = "Statement";

    /**
     * 侦测
     */
    String MONITOR_RULE = "monitorRule";


    /**
     * 服务编排
     */
    String AD_TEMPLATE = "adTemplate";

    /**
     * 行动
     */
    String ACTION = "action";

    /**
     * 任务
     */
    String TASK = "task";

    /**
     * 活动
     */
    String ACTIVITY = "activity";

    /**
     * 流程
     */
    String FLOW_GRAPH = "flowGraph";

    /**
     * 驱动执行
     */
    String DTD = "dtd";

    /**
     * 模型驱动
     */
    String MODEL_DRIVEN = "modelDriven";

    /**
     * 机制
     */
    String MECHANISM = "mechanism";

    /**
     * 套件作业
     */
    String KIT_ASSIGN = "kitAssign";

    /**
     * 数据视图
     */
    String DATA_VIEW = "dataView";

    /**
     * 流程
     */
    String PROCESS = "process";

    /**
     * 事件
     */
    String EVENT = "event";

    /**
     * 数据流
     */
    String DATA_FLOW = "dataFlow";
    /**
     * 租户级流程
     */
    String TENANT_PROCESS = "tenant_process";

    /**
     * 移动端
     */
    String MOBILE_PAGE_DESIGN = "mobilePageDesign";

    /**
     * 场景
     */
    String SCENE = "scene";

    /**
     * 子页面
     */
    String SUB_PAGE = "subPage";
    /**
     * 应用参数
     */
    String APP_PARAM = "appParam";

    /**
     * 租户级融合项目驱动执行
     */
    String TENANT_DTD = "tenant_dtd";

    /**
     * 工作台
     */
    String WORKBENCH_PORTAL = "WorkBenchPortal";
}
